<?php
require_once __DIR__ . "/config.php";         // اتصال به تنظیمات ثابت
require_once __DIR__ . "/button_handlers.php"; // اتصال به مدیریت دکمه‌ها

// تابع لاگ
function logDebug($message, $log_file = "debug.log") {
    file_put_contents(__DIR__ . "/$log_file", date("Y-m-d H:i:s") . " - " . $message . "\n", FILE_APPEND);
}

// تابع ارسال پیام
function sendMessage($chat_id, $text, $api_url, $reply_markup = null) {
    $data = [
        "chat_id" => $chat_id,
        "text" => $text,
        "reply_markup" => $reply_markup
    ];
    $response = file_get_contents($api_url . "sendMessage?" . http_build_query($data));
    logDebug("SendMessage to $chat_id: $text - Response: $response");
    return $response;
}

// تابع ویرایش پیام
function editMessage($chat_id, $message_id, $text, $api_url, $reply_markup = null) {
    if (!$message_id) {
        logDebug("Invalid message_id for chat_id: $chat_id");
        return false;
    }
    $data = [
        "chat_id" => $chat_id,
        "message_id" => $message_id,
        "text" => $text,
        "reply_markup" => $reply_markup
    ];
    $response = file_get_contents($api_url . "editMessageText?" . http_build_query($data));
    logDebug("EditMessage to $chat_id: $text - Response: $response");
    return $response;
}

// تابع ارسال فایل
function sendFile($chat_id, $file_data, $api_url, $caption = "") {
    $file_path = $file_data["tmp_name"];
    $file_name = $file_data["name"];
    $ext = pathinfo($file_name, PATHINFO_EXTENSION);
    
    $ch = curl_init();
    if (strtolower($ext) === 'png') {
        curl_setopt($ch, CURLOPT_URL, $api_url . "sendPhoto");
        $data = [
            "chat_id" => $chat_id,
            "photo" => new CURLFile($file_path, 'image/png', $file_name),
            "caption" => $caption
        ];
    } else { // HTML
        curl_setopt($ch, CURLOPT_URL, $api_url . "sendDocument");
        $data = [
            "chat_id" => $chat_id,
            "document" => new CURLFile($file_path, 'text/html', $file_name),
            "caption" => $caption
        ];
    }
    
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);
    
    logDebug("SendFile to $chat_id: $file_name - HTTP Code: $http_code - Response: $response");
    return $response;
}

// تابع ارسال عکس به مدیر
function sendPhotoToAdmin($chat_id, $photo_url, $username, $api_url, $admin_id) {
    $caption = "خرید جدید زدیم قربان 😍
    @$username";
    $data = [
        "chat_id" => $admin_id,
        "photo" => $photo_url,
        "caption" => $caption
    ];
    $response = file_get_contents($api_url . "sendPhoto?" . http_build_query($data));
    logDebug("SendPhoto to admin $admin_id: $caption - Response: $response");
    return $response;
}

// تابع ارسال درخواست به Flask
function sendStartRequest($user_id, $start_url, $request_type, $data = []) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $start_url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    $payload = array_merge([
        "user_id" => $user_id,
        "request_type" => $request_type
    ], $data);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload));
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);
    
    logDebug("SendStartRequest for user $user_id - HTTP Code: $http_code - Response: $response");
    return json_decode($response, true);
}

// تابع محاسبه تعداد روزهای ماه
function getDaysInMonth($month, $year) {
    $month = (int)$month;
    if ($month < 1 || $month > 12) return 31;
    if ($month == 2 && $year % 4 == 0 && ($year % 100 != 0 || $year % 400 == 0)) return 29;
    $days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    return $days[$month - 1];
}

// تابع بررسی بازه یک‌ساله
function isWithinOneYear($start_year, $start_month, $start_day, $end_year, $end_month, $end_day) {
    $start = new DateTime("$start_year-" . sprintf("%02d", $start_month) . "-" . sprintf("%02d", $start_day));
    $end = new DateTime("$end_year-" . sprintf("%02d", $end_month) . "-" . sprintf("%02d", $end_day));
    $interval = $start->diff($end);
    $days_diff = $interval->days;

    if ($end < $start) return "end_before_start";
    if ($days_diff > 366) return "exceeds_one_year";
    return true;
}

// تابع بررسی عضویت در کانال
function checkChannelMembership($chat_id, $channel_id, $api_url) {
    $data = [
        "chat_id" => $channel_id,
        "user_id" => $chat_id
    ];
    $response = file_get_contents($api_url . "getChatMember?" . http_build_query($data));
    $result = json_decode($response, true);
    logDebug("CheckMembership for user $chat_id in $channel_id - Response: $response");
    
    if ($result["ok"] && in_array($result["result"]["status"], ["member", "administrator", "creator"])) {
        return true; // کاربر عضو است
    }
    return false; // کاربر عضو نیست
}

// تابع ارسال پیام عضویت با دکمه‌های این‌لاین (هر دکمه در یک سطر)
function sendJoinChannelMessage($chat_id, $api_url) {
    $channel_id = "@episodetm";
    $inline_keyboard = [
        "inline_keyboard" => [
            [["text" => "عضویت در کانال", "url" => "https://t.me/episodetm"]]
        ]
    ];
    $text = "🎭 به اپیزود تیم خوش آمدید! 🎭

برای شروع، لطفاً ابتدا در کانال ما عضو شوید تا به امکانات ربات دسترسی داشته باشید.
سپس روی /start بزنید و لذت ببرید! 😎✨";
    sendMessage($chat_id, $text, $api_url, json_encode($inline_keyboard));
}

// پردازش درخواست‌های HTTP از Flask
if (!empty($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'POST' && !empty($_POST['chat_id'])) {
    $chat_id = $_POST['chat_id'];
    $text = $_POST['text'] ?? '';

    logDebug("Received HTTP POST request from Flask - chat_id: $chat_id, text: $text");
    logDebug("POST data: " . print_r($_POST, true));
    logDebug("FILES data: " . print_r($_FILES, true));

    if ($text === "backtest_done") {
        sendMessage($chat_id, "✅ بک‌تست شما انجام شد!", API_URL);
        if (isset($_FILES["episode_html"]) && isset($_FILES["episode_png"])) {
            sendFile($chat_id, $_FILES["episode_html"], API_URL, "فایل HTML بک‌تست");
            sendFile($chat_id, $_FILES["episode_png"], API_URL, "فایل PNG بک‌تست");
        }
        $user_data_file = __DIR__ . "/../data/user_$chat_id.json";
        $user_data = file_exists($user_data_file) ? json_decode(file_get_contents($user_data_file), true) : [];
        if (isset($user_data["final_message_id"])) {
            $final_text = "تاریخ شروع: {$user_data['start_year']}-{$user_data['start_month']}-{$user_data['start_day']}\nتاریخ پایان: {$user_data['end_year']}-{$user_data['end_month']}-{$user_data['end_day']}\nمارجین: {$user_data['margin']}\nلوریج: {$user_data['leverage']}\n✅ بک‌تست انجام شد";
            editMessage($chat_id, $user_data["final_message_id"], $final_text, API_URL);
        }
    } elseif (strpos($text, "Sending episode.html") === 0) {
        if (isset($_FILES["episode_html"])) {
            sendFile($chat_id, $_FILES["episode_html"], API_URL, "فایل HTML بک‌تست");
        }
    } elseif (strpos($text, "Sending episode.png") === 0) {
        if (isset($_FILES["episode_png"])) {
            sendFile($chat_id, $_FILES["episode_png"], API_URL, "فایل PNG بک‌تست");
        }
    } elseif ($text === "process_now") {
        $user_data_file = __DIR__ . "/../data/user_$chat_id.json";
        $user_data = file_exists($user_data_file) ? json_decode(file_get_contents($user_data_file), true) : [];
        if (!empty($user_data)) {
            $data = [
                "start_year" => $user_data["start_year"],
                "start_month" => $user_data["start_month"],
                "start_day" => $user_data["start_day"],
                "end_year" => $user_data["end_year"],
                "end_month" => $user_data["end_month"],
                "end_day" => $user_data["end_day"],
                "margin" => $user_data["margin"],
                "leverage" => $user_data["leverage"]
            ];
            sendStartRequest($chat_id, START_URL, REQUEST_TYPE, $data);
        }
    }
    exit;
}

// پردازش آپدیت‌های تلگرام
$update = json_decode(file_get_contents("php://input"), true);
$chat_id = $update["message"]["chat"]["id"] ?? $update["callback_query"]["message"]["chat"]["id"] ?? null;
$message_id = $update["message"]["message_id"] ?? $update["callback_query"]["message"]["message_id"] ?? null;
$text = $update["message"]["text"] ?? "";
$callback_data = $update["callback_query"]["data"] ?? "";
$photo = $update["message"]["photo"] ?? null;
$username = $update["message"]["chat"]["username"] ?? "بدون نام کاربری";

$user_data_file = __DIR__ . "/../data/user_$chat_id.json";
$user_data = file_exists($user_data_file) ? json_decode(file_get_contents($user_data_file), true) : [];

// تنظیم مقدار پیش‌فرض برای is_backtest_active
if (!array_key_exists("is_backtest_active", $user_data)) {
    $user_data["is_backtest_active"] = 1; // پیش‌فرض فعال
}

// لاگ برای بررسی مقدار is_backtest_active
logDebug("Initial is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);

// بارگذاری زمان آخرین اجرای 📊 بک تست آنلاین
$last_start_data = file_exists(LAST_START_FILE) ? json_decode(file_get_contents(LAST_START_FILE), true) : [];
if (!is_array($last_start_data)) $last_start_data = [];

if ($chat_id && ($text || $callback_data || $photo)) {
    // بررسی عضویت در کانال قبل از هر عملی
    if (!checkChannelMembership($chat_id, "@episodetm", API_URL)) {
        sendJoinChannelMessage($chat_id, API_URL);
    } else {
        if ($text == "/start") {
            $keyboard = [
                "keyboard" => [
                    ["🤖 ربات اتوماتیک ترید"],
                    ["📊 بک تست آنلاین"],
                    ["📢 کانال ما", "📲 پشتیبانی مستقیم"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, "❤️‍🔥 - به اپیزود خوش اومدی

👨‍💻 - اپیزود تیم با ارائه راهکارهای هوشمند، به شما در مدیریت معاملات و بهینه‌سازی استراتژی‌های ترید کمک می‌کند.

برای شروع، از منوی زیر استفاده کنید👇", API_URL, json_encode($keyboard));
            $user_data["step"] = "main_menu";
            // نکته: اینجا is_backtest_active بازنشانی نمی‌شود تا مقدار قبلی حفظ شود
            logDebug("After /start - is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);
        } elseif ($text == "/enable") { // دستور برای فعال کردن
            $user_data["is_backtest_active"] = 1;
            sendMessage($chat_id, "✅ بک‌تست فعال شد.", API_URL);
            logDebug("Enabled is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);
        } elseif ($text == "/disable") { // دستور برای غیرفعال کردن
            $user_data["is_backtest_active"] = 0;
            sendMessage($chat_id, "❌ بک‌تست غیرفعال شد.", API_URL);
            logDebug("Disabled is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);
        } elseif ($callback_data == "joined_channel") {
            // وقتی کاربر دکمه "عضو شدم" رو زد
            if (checkChannelMembership($chat_id, "@episodetm", API_URL)) {
                $keyboard = [
                    "keyboard" => [
                        ["🤖 ربات اتوماتیک ترید"],
                        ["📊 بک تست آنلاین"],
                        ["📢 کانال ما", "📲 پشتیبانی مستقیم"]
                    ],
                    "resize_keyboard" => true,
                    "one_time_keyboard" => false
                ];
                editMessage($chat_id, $message_id, "✅ عضویت شما تأیید شد! حالا می‌تونید از ربات استفاده کنید.", API_URL, json_encode($keyboard));
                $user_data["step"] = "main_menu";
            } else {
                sendMessage($chat_id, "شما هنوز در کانال عضو نشدید! لطفاً ابتدا عضو شوید.", API_URL);
            }
        } elseif ($text == "🤖 ربات اتوماتیک ترید") {
            $new_keyboard = [
                "keyboard" => [
                    ["🌟ربات اپیزود پرو", "⭐️ربات اپیزود پلاس"],
                    ["بازگشت 🔙"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, " ربات موردنظر خود را انتخاب کنید 👇", API_URL, json_encode($new_keyboard));
            $user_data["step"] = "select_robot";
        } elseif ($text == "🌟ربات اپیزود پرو") {
            $robot_keyboard = [
                "keyboard" => [
                    ["📥دریافت"],
                    ["بازگشت 🔙"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, "📌 معرفی ربات ترید اپیزود پرو

🔥 نسخه حرفه‌ای ربات ترید برای متاتریدر 4 و 5
اپیزود پرو نسخه پیشرفته‌تر و دقیق‌تر اپیزود پلاس است که با استفاده از هوش مصنوعی و تکنیک‌های پرایس‌اکشن، معاملات بهینه‌تری انجام می‌دهد. این ربات کاملاً توسط تیم اپیزود کدنویسی شده و برای تریدرهایی مناسب است که به دنبال وین‌ریت بالاتر و استراتژی‌های قوی‌تر هستند.

💡 ویژگی‌های اپیزود پرو:

✅ وین ریت: 85%
✅ تعداد معاملات روزانه: 5 تا 70 معامله
✅ ریوارد به ریسک: 3 برابر
✅ حداقل سرمایه مورد نیاز: 100 دلار (یا حساب سنتی برای مبالغ کمتر)
✅ قابل اجرا روی متاتریدر 4 و 5
✅ امکان تنظیم حد ضرر و ریسک به‌صورت دستی
✅ معاملات در بازارهای: طلا، ین ژاپن

📦 محتوای پکیج اپیزود پرو:

با خرید این پکیج، شما به 3 ربات پیشرفته از سری AI پرایس اکشن دسترسی خواهید داشت:
1️⃣ ربات AI اپیزود (MT4)
2️⃣ ربات AI اپیزود (mt5)
3️⃣ ربات مخصوص پراپ
 
🎥 مشاهده عملکرد ربات
برای مشاهده بک‌تست‌ها و ویدیوهای آموزشی، به کانال تلگرام ما مراجعه کنید:
📌 @episodetm

⛔ توجه:
🔸 به دلیل باز بودن سورس ربات برای شرکت‌های پراپ، امکان ارائه نسخه تست وجود ندارد", API_URL, json_encode($robot_keyboard));
            $user_data["selected_robot"] = "robot1";
        } elseif ($text == "⭐️ربات اپیزود پلاس") {
            $robot_keyboard = [
                "keyboard" => [
                    ["📥دریافت"],
                    ["بازگشت 🔙"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, "📌 معرفی ربات ترید اپیزود پلاس

🚀 ربات هوشمند ترید برای متاتریدر 4 و 5
اپیزود پلاس یک ربات ترید خودکار است که بر روی متاتریدر شما نصب شده و با تحلیل دقیق بازار، معاملات را به‌صورت خودکار انجام می‌دهد. این ربات به طور کامل توسط تیم اپیزود طراحی و کدنویسی شده و عملکردی متفاوت از سایر ربات‌های موجود دارد.

💡 ویژگی‌های اپیزود:

✅ وین ریت: 60%
✅ تعداد معاملات روزانه: 1 تا 20 معامله
✅ ریوارد به ریسک: 2 برابر
✅ حداقل سرمایه مورد نیاز: 100 دلار (یا حساب سنتی برای مبالغ کمتر)
✅ قابل اجرا روی متاتریدر 4 و 5
✅ امکان تنظیم حد ضرر و ریسک به‌صورت دستی
✅ معاملات در بازارهای: یورو، داوجونز

📦 محتوای پکیج اپیزود پلاس:

با خرید این پکیج، شما به 3 ربات پیشرفته از سری Episode دسترسی خواهید داشت:
1️⃣ ربات اپیزود (MT4)
2️⃣ ربات اپیزود (MT5)
3️⃣ ربات مخصوص پراپ

🎥 مشاهده عملکرد ربات
برای مشاهده بک‌تست‌ها و ویدیوهای آموزشی، به کانال تلگرام ما مراجعه کنید:
📌 @episodetm

⛔ توجه:
🔸 به دلیل باز بودن سورس ربات برای شرکت‌های پراپ، امکان ارائه نسخه تست وجود ندارد", API_URL, json_encode($robot_keyboard));
            $user_data["selected_robot"] = "robot2";
        } elseif ($text == "📥دریافت" && isset($user_data["selected_robot"])) {
            $back_keyboard = [
                "keyboard" => [
                    ["بازگشت 🔙"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            if ($user_data["selected_robot"] == "robot1") {
                sendMessage($chat_id, "🔰 | لطفا ابتدا به این شماره کارت مبلغ را واریز کنید 
  
🔔 | در‎صورت تمایل به خرید و تایید قوانین بعد از پرداخت رسید خود را برای بات ارسال کنید سپس بعد از تایید ادمین سرویس برای شما ارسال خواهد شد


💳 | شمارت کارت : 
6219861940637290  

👤 | نام : ایلیا رسا

💵 | مبلغ :6,980,000 تومان", API_URL, json_encode($back_keyboard));
            } elseif ($user_data["selected_robot"] == "robot2") {
                sendMessage($chat_id, "🔰 | لطفا ابتدا به این شماره کارت مبلغ را واریز کنید 
  
🔔 | در‎صورت تمایل به خرید و تایید قوانین بعد از پرداخت رسید خود را برای بات ارسال کنید سپس بعد از تایید ادمین سرویس برای شما ارسال خواهد شد


💳 | شمارت کارت : 
6219861940637290  

👤 | نام : ایلیا رسا

💵 | مبلغ :4,980,000 تومان", API_URL, json_encode($back_keyboard));
            }
            $user_data["step"] = "awaiting_photo";
        } elseif ($photo && isset($user_data["step"]) && $user_data["step"] == "awaiting_photo") {
            $photo_url = $photo[count($photo) - 1]["file_id"];
            sendPhotoToAdmin($chat_id, $photo_url, $username, API_URL, ADMIN_ID);
            sendMessage($chat_id, "✅خرید شما در حال بررسی توسط ادمین ما می‌باشد. 
پس از انجام بررسی، ادمین‌های ما با شما در ارتباط خواهند بود.", API_URL);
            
            $keyboard = [
                "keyboard" => [
                    ["🤖 ربات اتوماتیک ترید"],
                    ["📊 بک تست آنلاین"],
                    ["📢 کانال ما", "📲 پشتیبانی مستقیم"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, "❤️‍🔥 - به اپیزود خوش اومدی

👨‍💻 - اپیزود تیم با ارائه راهکارهای هوشمند، به شما در مدیریت معاملات و بهینه‌سازی استراتژی‌های ترید کمک می‌کند.

برای شروع، از منوی زیر استفاده کنید👇", API_URL, json_encode($keyboard));
            $user_data["step"] = "main_menu";
            unset($user_data["selected_robot"]);
        } elseif ($text == "بازگشت 🔙") {
            $keyboard = [
                "keyboard" => [
                    ["🤖 ربات اتوماتیک ترید"],
                    ["📊 بک تست آنلاین"],
                    ["📢 کانال ما", "📲 پشتیبانی مستقیم"]
                ],
                "resize_keyboard" => true,
                "one_time_keyboard" => false
            ];
            sendMessage($chat_id, "❤️‍🔥 - به اپیزود خوش اومدی

👨‍💻 - اپیزود تیم با ارائه راهکارهای هوشمند، به شما در مدیریت معاملات و بهینه‌سازی استراتژی‌های ترید کمک می‌کند.

برای شروع، از منوی زیر استفاده کنید👇", API_URL, json_encode($keyboard));
            $user_data["step"] = "main_menu";
            unset($user_data["selected_robot"]);
        } elseif ($text == "📊 بک تست آنلاین") {
            logDebug("Checking is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);
            if ($user_data["is_backtest_active"] == 1) {
                require_once __DIR__ . "/backtest_handler.php";
                handleBacktestStart($chat_id, API_URL, START_URL, REQUEST_TYPE, ADMIN_ID, LAST_START_FILE, WAIT_FILE, $user_data, $last_start_data);
            } else {
                sendMessage($chat_id, "❌ این بخش برای اپدیت تا دقایقی دیگر غیرفعال است.", API_URL);
            }
        } elseif ($text == "📢 کانال ما") {
            handleChannelButton($chat_id, API_URL);
        } elseif ($text == "📲 پشتیبانی مستقیم") {
            handleSupportButton($chat_id, API_URL);
        } else {
            logDebug("Else clause - is_backtest_active for user $chat_id: " . $user_data["is_backtest_active"]);
            if ($user_data["is_backtest_active"] == 1) {
                require_once __DIR__ . "/backtest_handler.php";
                handleBacktest($chat_id, $text, $callback_data, $message_id, API_URL, START_URL, REQUEST_TYPE, $user_data, WAIT_FILE);
            } else {
                sendMessage($chat_id, "❌ این بخش غیرفعال است.", API_URL);
            }
        }
    }
}

file_put_contents($user_data_file, json_encode($user_data));
?>